DEFAULT_BASE_URL = "https://public-api.etoro.com"
DEFAULT_WS_URL = "wss://ws.etoro.com/ws"
API_VERSION = "v1"
API_PREFIX = f"/api/{API_VERSION}"

MAX_RATE_INSTRUMENT_IDS = 100
MAX_CANDLES = 1000

DEFAULT_TIMEOUT = 30.0  # seconds
DEFAULT_RETRY_ATTEMPTS = 3
DEFAULT_RETRY_DELAY = 1.0  # seconds

DEFAULT_RATE_LIMIT_MAX_REQUESTS = 20
DEFAULT_RATE_LIMIT_WINDOW = 10.0  # seconds

DEFAULT_WS_RECONNECT_ATTEMPTS = 10
DEFAULT_WS_RECONNECT_DELAY = 1.0  # seconds
DEFAULT_WS_AUTH_TIMEOUT = 10.0  # seconds
DEFAULT_WS_HEARTBEAT_INTERVAL = 30.0  # seconds
DEFAULT_WS_HEARTBEAT_TIMEOUT = 10.0  # seconds
